/*
 * =====================================================================================
 *
 *       Filename:  gensinus.c
 *
 *    Description:  Generate sinus table and write it to file
 *
 *        Version:  1.0
 *        Created:  22.12.2017 15:25:14
 *       Revision:  none
 *       Compiler:  gcc
 *
 *         Author:  Simon Ferber (https://www.ist-schlau.de), simon@ist-schlau.de
 *   Organization:  Kiwi Homebrew Computer
 *
 * =====================================================================================
 */

#include <stdio.h>
#include <math.h>

int main ()
{
    int i;
    float rad;
    int aSin[512];
    FILE *fp = NULL;

    /* create sin lookup table */
    for (i = 0; i < 512; i++)
    {
        rad =  ((float)i * 0.703125) * 0.0174532; /* 360 / 512 * degree to rad, 360 degrees spread over 512 values to be able to use AND 512-1 instead of using modulo 360*/
        aSin[i] = sin(rad) * 128; /*using fixed point math with 1024 as base*/
        printf(".");
        fflush(stdout);
        printf("\n");
    }

    /* write sin table to file sintable.h */
    //fp = fopen("sintab.h", "w");
    //if( fp != NULL )
    {
        printf("#ifndef _SINTABLE_H\n");
        printf("#define _SINTABLE_H\n");
        printf("static int16_t aSin[] =\n");
        printf("{\n");
        for (i = 0; i < 512; i++)
        {
            printf("\t%i,", aSin[i]);
            if (!((i+1)%16))
            {
                printf("\n");
            } else
            {
                printf(" ");
            }

        }

        printf("};\n");
        printf("#endif\n");
    }
    return 0;
}
